import bpy

bl_info = \
	{
		"name" : "Enable Legacy Pose Panel",
		"author" : "jackie",
		"version" : (4, 2, 0),
		"blender" : (2, 80, 0),
		"description" : "woah",
		"category" : "Object Data",
	}

def LegacyPosePanel(self, context):
    layout = self.layout
    col = layout.column(align=True)
    col.label(text="This panel is a remainder of the old pose library,")
    col.label(text="which was not ready to be replaced by the Asset Browser yet!")
    url = self.get_manual_url()
    col.operator("wm.url_open", text="More Info", icon='URL').url = url
    layout.separator()
    ob = context.object
    poselib = ob.pose_library
    col = layout.column(align=True)
    col.template_ID(ob, "pose_library", new="poselib.new", unlink="poselib.unlink")
    if poselib:
        if hasattr(bpy.types, "POSELIB_OT_convert_old_object_poselib"):
            col.operator("poselib.convert_old_object_poselib",
                         text="Convert to Pose Assets", icon='ASSET_MANAGER')
        else:
            col.label(text="Enable the Pose Library add-on to convert", icon='ERROR')
            col.label(text="this legacy pose library to pose assets", icon='BLANK1')
        # Put the deprecated stuff in its own sub-layout.
        dep_layout = layout.column()
        dep_layout.active = True
        # warning about poselib being in an invalid state
        if poselib.fcurves and not poselib.pose_markers:
            dep_layout.label(
                icon='ERROR',
                text="Error: Potentially corrupt library, run 'Sanitize' operator to fix",
            )
        # list of poses in pose library
        row = dep_layout.row()
        row.template_list("UI_UL_list", "pose_markers", poselib, "pose_markers",
                          poselib.pose_markers, "active_index", rows=3)
        # column of operators for active pose
        # - goes beside list
        col = row.column(align=True)
        # invoke should still be used for 'add', as it is needed to allow
        # add/replace options to be used properly
        col.operator("poselib.pose_add", icon='ADD', text="")
        col.operator_context = 'EXEC_DEFAULT'  # exec not invoke, so that menu doesn't need showing
        pose_marker_active = poselib.pose_markers.active
        if pose_marker_active is not None:
            col.operator("poselib.pose_remove", icon='REMOVE', text="")
            col.operator(
                "poselib.apply_pose",
                icon='ZOOM_SELECTED',
                text="",
            ).pose_index = poselib.pose_markers.active_index
        col.operator("poselib.action_sanitize", icon='HELP', text="")  # XXX: put in menu?
        if pose_marker_active is not None:
            col.operator("poselib.pose_move", icon='TRIA_UP', text="").direction = 'UP'
            col.operator("poselib.pose_move", icon='TRIA_DOWN', text="").direction = 'DOWN'

def register():
    # bpy.types.DATA_PT_pose_library.append(EnablePosePanel)
    bpy.types.DATA_PT_pose_library.draw = LegacyPosePanel


def unregister():
   # bpy.types.DATA_PT_pose_library.remove(EnablePosePanel)
   bpy.types.DATA_PT_pose_library.draw = LegacyPosePanel

if __name__ == "__main__":
    register()
