import bpy

bl_info = \
	{
		"name" : "Damn Simple Pose Library 1",
		"author" : "jackie",
		"version" : (1),
		"blender" : (2, 80, 0),
		"description" : "woah",
		"category" : "Object Data",
	}

# Panel to display pose management UI
class PoseManagerPanel(bpy.types.Panel):
    bl_label = "Damn Simple Pose Library"
    bl_idname = "OBJECT_PT_pose_manager"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Pose'

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        armature = context.active_object

        # Pose selection dropdown
        layout.label(text="Pose Selection:")
        layout.prop(scene, "pose_keyframe_index", text="Keyframe")

        # Save and Load buttons
        row = layout.row(align=True)
        row.operator("pose_manager.save_pose", text="Save Pose")
        row.operator("pose_manager.load_pose", text="Load Pose")

        # Pose name input
        layout.prop(scene, "pose_name", text="Pose Name")

        # Save and Load buttons
        row = layout.row(align=True)
        row.operator("pose_manager.save_named_pose", text="Save Named Pose")
        row.operator("pose_manager.load_named_pose", text="Load Named Pose")


# Operator to save the current pose to a keyframe
class SavePoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.save_pose"
    bl_label = "Save Pose"

    def execute(self, context):
        armature = context.active_object
        keyframe_index = context.scene.pose_keyframe_index

        # Insert keyframe for selected bones' pose
        for bone in armature.pose.bones:
            if bone.bone.select:
                bone.keyframe_insert(data_path="location", index=-1, frame=keyframe_index)
                bone.keyframe_insert(data_path="rotation_quaternion", index=-1, frame=keyframe_index)
                bone.keyframe_insert(data_path="scale", index=-1, frame=keyframe_index)

        return {'FINISHED'}


# Operator to load a pose from a keyframe
class LoadPoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.load_pose"
    bl_label = "Load Pose"

    def execute(self, context):
        armature = context.active_object
        keyframe_index = context.scene.pose_keyframe_index

        # Load pose from selected keyframe
        bpy.context.scene.frame_set(keyframe_index)
        bpy.ops.pose.select_all(action='DESELECT')
        for bone in armature.pose.bones:
            if bone.bone.select:
                bone.bone.select = False
                bone.bone.select = True

        return {'FINISHED'}


# Operator to save the current pose to a named keyframe
class SaveNamedPoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.save_named_pose"
    bl_label = "Save Named Pose"

    def execute(self, context):
        armature = context.active_object
        keyframe_index = context.scene.pose_keyframe_index
        pose_name = context.scene.pose_name

        # Insert keyframe for selected bones' pose
        for bone in armature.pose.bones:
            if bone.bone.select:
                bone.keyframe_insert(data_path="location", index=-1, frame=keyframe_index, group=pose_name)
                bone.keyframe_insert(data_path="rotation_quaternion", index=-1, frame=keyframe_index, group=pose_name)
                bone.keyframe_insert(data_path="scale", index=-1, frame=keyframe_index, group=pose_name)

        return {'FINISHED'}


# Operator to load a pose from a named keyframe
class LoadNamedPoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.load_named_pose"
    bl_label = "Load Named Pose"

    def execute(self, context):
        armature = context.active_object
        keyframe_index = context.scene.pose_keyframe_index
        pose_name = context.scene.pose_name

        # Load pose from selected keyframe
        bpy.context.scene.frame_set(keyframe_index)
        bpy.ops.pose.select_all(action='DESELECT')
        for bone in armature.pose.bones:
            if bone.bone.select:
                bone.bone.select = False
                bone.bone.select = True

        return {'FINISHED'}


# Register classes
def register():
    bpy.utils.register_class(PoseManagerPanel)
    bpy.utils.register_class(SavePoseOperator)
    bpy.utils.register_class(LoadPoseOperator)
    bpy.utils.register_class(SaveNamedPoseOperator)
    bpy.utils.register_class(LoadNamedPoseOperator)
    bpy.types.Scene.pose_keyframe_index = bpy.props.IntProperty(name="Keyframe Index", default=1)
    bpy.types.Scene.pose_name = bpy.props.StringProperty(name="Pose Name", default="Pose")


# Unregister classes
def unregister():
    bpy.utils.unregister_class(PoseManagerPanel)
    bpy.utils.unregister_class(SavePoseOperator)
    bpy.utils.unregister_class(LoadPoseOperator)
    bpy.utils.unregister_class(SaveNamedPoseOperator)
    bpy.utils.unregister_class(LoadNamedPoseOperator)
    del bpy.types.Scene.pose_keyframe_index
    del bpy.types.Scene.pose_name


# Run script
if __name__ == "__main__":
    register()
