import bpy

bl_info = \
	{
		"name" : "Damn Simple Pose Library",
		"author" : "jackie",
		"version" : (4, 3, 0),
		"blender" : (2, 80, 0),
		"description" : "woah",
		"category" : "Object Data",
	}
import bpy


# Panel to display pose management UI
class PoseManagerPanel(bpy.types.Panel):
    bl_label = "Damn Simple Pose Library"
    bl_idname = "OBJECT_PT_pose_manager"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Pose'

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        armature = context.active_object

        # Dropdown for existing action objects
        layout.prop_search(scene, "selected_action", bpy.data, "actions", text="Action")

        # Pose selection dropdown
        layout.label(text="Pose Selection:")
        layout.prop(scene, "pose_keyframe_index", text="Keyframe")

        # Save and Load buttons
        row = layout.row(align=True)
        row.operator("pose_manager.save_pose", text="Save Pose")
        row.operator("pose_manager.load_pose", text="Load Pose")

        # List saved poses
        layout.label(text="Saved Poses:")
        if scene.selected_action is not None:
            action = bpy.data.actions.get(scene.selected_action)
            if action:
                pose_markers = action.pose_markers
                for marker in pose_markers:
                    row = layout.row()
                    row.label(text=marker.name)
                    row.operator("pose_manager.load_named_pose", text="Load").pose_marker_index = pose_markers.find(marker.name)
                    row.operator("pose_manager.delete_named_pose", text="Delete").pose_marker_index = pose_markers.find(marker.name)


# Operator to save the current pose to a keyframe
class SavePoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.save_pose"
    bl_label = "Save Pose"

    def execute(self, context):
        armature = context.active_object
        action = bpy.data.actions.get(context.scene.selected_action)
        keyframe_index = context.scene.pose_keyframe_index

        # Insert keyframe for selected bones' pose
        for bone in armature.pose.bones:
            if bone.bone.select:
                bone.keyframe_insert(data_path="location", index=-1, frame=keyframe_index)
                bone.keyframe_insert(data_path="rotation_quaternion", index=-1, frame=keyframe_index)
                bone.keyframe_insert(data_path="scale", index=-1, frame=keyframe_index)

        # Create marker
        if action:
            marker = action.pose_markers.new(name=str(keyframe_index), frame=keyframe_index)

        return {'FINISHED'}


# Operator to load a pose from a keyframe
class LoadPoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.load_pose"
    bl_label = "Load Pose"

    def execute(self, context):
        armature = context.active_object
        keyframe_index = context.scene.pose_keyframe_index

        # Load pose from selected keyframe
        bpy.context.scene.frame_set(keyframe_index)
        bpy.ops.pose.select_all(action='DESELECT')
        for bone in armature.pose.bones:
            if bone.bone.select:
                bone.bone.select = False
                bone.bone.select = True

        return {'FINISHED'}


# Operator to load a named pose from a keyframe
class LoadNamedPoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.load_named_pose"
    bl_label = "Load Named Pose"
    pose_marker_index: bpy.props.IntProperty()

    def execute(self, context):
        action = bpy.data.actions.get(context.scene.selected_action)
        if action:
            marker = action.pose_markers[self.pose_marker_index]
            bpy.context.scene.frame_set(marker.frame)
        return {'FINISHED'}


# Operator to delete a named pose marker
class DeleteNamedPoseOperator(bpy.types.Operator):
    bl_idname = "pose_manager.delete_named_pose"
    bl_label = "Delete Named Pose"
    pose_marker_index: bpy.props.IntProperty()

    def execute(self, context):
        action = bpy.data.actions.get(context.scene.selected_action)
        if action:
            action.pose_markers.remove(action.pose_markers[self.pose_marker_index])
        return {'FINISHED'}


# Register classes
def register():
    bpy.utils.register_class(PoseManagerPanel)
    bpy.utils.register_class(SavePoseOperator)
    bpy.utils.register_class(LoadPoseOperator)
    bpy.utils.register_class(LoadNamedPoseOperator)
    bpy.utils.register_class(DeleteNamedPoseOperator)
    bpy.types.Scene.pose_keyframe_index = bpy.props.IntProperty(name="Keyframe Index", default=1)
    bpy.types.Scene.selected_action = bpy.props.StringProperty(name="Selected Action")


# Unregister classes
def unregister():
    bpy.utils.unregister_class(PoseManagerPanel)
    bpy.utils.unregister_class(SavePoseOperator)
    bpy.utils.unregister_class(LoadPoseOperator)
    bpy.utils.unregister_class(LoadNamedPoseOperator)
    bpy.utils.unregister_class(DeleteNamedPoseOperator)
    del bpy.types.Scene.pose_keyframe_index
    del bpy.types.Scene.selected_action


# Run script
if __name__ == "__main__":
    register()
