# SPDX-FileCopyrightText: 2021-2023 Blender Foundation
#
# SPDX-License-Identifier: GPL-2.0-or-later

"""
Pose Library - GUI definition.
"""

import bpy
from .common import getArmatureObject, getPoseLib


# Panel to display pose management UI
class DATA_PT_PoseManagerPanel(bpy.types.Panel):
    bl_label = "Damn Simple Pose Library"
    bl_id = "DATA_PT_PoseManagerPanel"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Pose'

    def draw(self, context):
        scene = context.scene
        active_obj = context.active_object
        arm_object = getArmatureObject(context)
        test1 = "woah"

        dspl_panel_layout = self.layout

        armature_layout = dspl_panel_layout.column()
        if arm_object:
            if arm_object == active_obj:
                armature_layout.label(text=arm_object.name + " (Active)")
            elif arm_object == active_obj.parent:
                armature_layout.label(text=arm_object.name + " (Parent)")
            
            armature_layout.template_ID(arm_object.animation_data, "action", new="dspl.create_pose_library")
            if arm_object.animation_data.action:
                pose_object = getPoseLib(context)
            elif arm_object.animation_data.action is None:
                armature_layout.label(text="No Pose library action detected")
                armature_layout.operator("dspl.create_pose_library", text="Create Pose Library", icon="PLUS")

            # list of poses in pose library
            if arm_object.animation_data.action:
                pose_box = dspl_panel_layout.row()
                pose_layout = pose_box.column()
                action = arm_object.animation_data.action
                pose_layout.template_list("UI_UL_list", "pose_markers", action, "pose_markers",
                    action.pose_markers, "active_index", rows=4)

                # pose operators
                pose_ops = pose_box.column(align=True)
                pose_ops.operator("dspl.save_pose_menu", icon='ADD', text="")
                pose_marker_active = action.pose_markers.active
                if pose_marker_active is not None:
                    pose_ops.operator("dspl.delete_pose", icon='REMOVE', text="")
                    pose_ops.operator(
                        "dspl.load_pose",
                        icon='ZOOM_SELECTED',
                        text="",
                    )# .pose_index = action.pose_markers.active_index
                    pose_ops.operator("dspl.move_pose", icon='TRIA_UP', text="").direction = "UP"
                    pose_ops.operator("dspl.move_pose", icon='TRIA_DOWN', text="").direction = "DOWN"




        else:
            armature_layout.label(text="No armature or parent selected")

        testing_layout = dspl_panel_layout.box()
        testing_layout.label(text="Testing")
        testing_layout.operator("dspl.test", text="Test")
        testing_layout.operator("dspl.test2", text="Test2")
        testing_layout.operator("dspl.test3", text="Test3")

class OBJECT_MT_CreatePoseMenu(bpy.types.Menu):
    bl_idname = "OBJECT_MT_CreatePoseMenu"
    bl_label = "Create Pose"
    
    posename: bpy.props.StringProperty(name="Pose")

    def draw(self, context):
        scene = context.scene
        layout = self.layout

        layout.label(text="Test")
        layout.prop(scene, "posename", text="")

        layout.operator("dspl.save_pose", text="Save Pose")

classes = (
    DATA_PT_PoseManagerPanel,
    OBJECT_MT_CreatePoseMenu,
    # DATA_PT_damn_simple_pose_library,
)

register, unregister = bpy.utils.register_classes_factory(classes)
