import bpy
from bpy.types import Object, Scene
from bpy.props import PointerProperty
from .common import getArmatureObject, getPoseLib
from .gui import *

class testOp(bpy.types.Operator):
    bl_idname = "dspl.test"
    bl_label = "Test1"

    def execute(self, context):
        arm_object = getArmatureObject(context)
        pose_object = getPoseLib(context)
        print("test")
        print("")
        print(arm_object.name)
        print(pose_object.name)
        return {'FINISHED'}

class testOp2(bpy.types.Operator):
    bl_idname = "dspl.test2"
    bl_label = "Test2"

    def execute(self, context):
        print()
        print()
        print(bpy.context.window_manager.test1)
        return {'FINISHED'}

class testOp3(bpy.types.Operator):
    bl_idname = "dspl.test3"
    bl_label = "Test3"
    # target_obj: bpy.props.StringProperty()
    def execute(self, context):
        arm_obj = getArmatureObject(context)
        pose_items = arm_obj.animation_data.action.pose_markers.keys()
        print(pose_items)
        return {'FINISHED'}

        

# Operator to create a new pose library
class DSPL_OT_CreatePoseLibrary(bpy.types.Operator):
    bl_idname = "dspl.create_pose_library"
    bl_label = "Create Pose Library"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        arm_object = getArmatureObject(context)
        action = bpy.data.actions.new(name=arm_object.name + "_PoseLib")
        arm_object.animation_data.action = action

        return {'FINISHED'}

# Operator to save the current pose to a keyframe
class DSPL_OT_SavePoseMenu(bpy.types.Operator):
    bl_idname = "dspl.save_pose_menu"
    bl_label = "Save Pose"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.ops.wm.call_menu(name=OBJECT_MT_CreatePoseMenu.bl_idname)

        return {'FINISHED'}


# Operator to save the current pose to a keyframe
class DSPL_OT_SavePose(bpy.types.Operator):
    bl_idname = "dspl.save_pose"
    bl_label = "Save Pose"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        arm_object = getArmatureObject(context)
        pose_markers = arm_object.animation_data.action.pose_markers
        new_marker = len(pose_markers) + 1
        active_marker = pose_markers.active_index

        # Insert keyframe for selected bones' pose
        for bone in arm_object.pose.bones:
            if bone.bone.select:
                bone.keyframe_insert(data_path="location", index=-1, frame=new_marker, group=bone.name)
                bone.keyframe_insert(data_path="rotation_quaternion", index=-1, frame=new_marker, group=bone.name)
                bone.keyframe_insert(data_path="scale", index=-1, frame=new_marker, group=bone.name)
        pose_markers.new(name="Test1")
        print("Saved pose - ")

        return {'FINISHED'}


# Operator to load a pose from a keyframe
class DSPL_OT_LoadPose(bpy.types.Operator):
    bl_idname = "dspl.load_pose"
    bl_label = "Load Pose"

    def execute(self, context):
        
        print("Loaded pose - ")

        return {'FINISHED'}

# Operator to delete a pose from a keyframe
class DSPL_OT_DeletePose(bpy.types.Operator):
    bl_idname = "dspl.delete_pose"
    bl_label = "Delete Pose"

    def execute(self, context):
        armature = context.active_object
        keyframe_index = context.scene.pose_keyframe_index

        # Delete pose from selected keyframe
        bpy.context.scene.frame_set(keyframe_index)
        bpy.ops.pose.select_all(action='DESELECT')
        for bone in armature.pose.bones:
            if bone.bone.select:
                bone.bone.select = False
                bone.bone.select = True

        return {'FINISHED'}

# Operator to move a pose from a keyframe
class DSPL_OT_MovePose(bpy.types.Operator):
    bl_idname = "dspl.move_pose"
    bl_label = "Move Pose"
    direction: bpy.props.StringProperty(name="Direction", default="DOWN")

    def execute(self, context):
        if self.direction == "UP":
            move_dir = -1
        elif self.direction == "DOWN":
            move_dir = 1
        arm_object = getArmatureObject(context)
        pose_markers = arm_object.animation_data.action.pose_markers
        pose_items = pose_markers.items()
        active_marker = pose_markers.active_index
        moving_marker = pose_markers.items().pop(active_marker)

        pose_items.insert(active_marker + move_dir, moving_marker)
        pose_markers.active_index = active_marker + move_dir
        print(pose_items)
       # arm_object.data.update()

        

        return {'FINISHED'}

classes = (
   testOp,
   testOp2,
   testOp3,
   DSPL_OT_CreatePoseLibrary,
   DSPL_OT_SavePoseMenu,
   DSPL_OT_SavePose,
   DSPL_OT_LoadPose,
   DSPL_OT_DeletePose,
   DSPL_OT_MovePose
)

register, unregister = bpy.utils.register_classes_factory(classes)
