bl_info = \
	{
		"name" : "Damn Simple Pose Library",
		"author" : "jackie",
		"version" : (4, 1, 0),
		"blender" : (3, 0, 0),
		"description" : "woah",
		"category" : "Object Data",
	}

import bpy
from typing import List, Tuple

_need_reload = "operators" in locals()
from . import gui, operators, common

if _need_reload:
    import importlib

    gui = importlib.reload(gui)
    common = importlib.reload(common)
    operators = importlib.reload(operators)

class dsplObj(bpy.types.PropertyGroup):
    pose_library: bpy.props.PointerProperty(name="Active Pose Library", description="", override = {'LIBRARY_OVERRIDABLE'}, type=bpy.types.Action)

class dsplVars(bpy.types.PropertyGroup):
    pose_index: bpy.props.IntProperty(name="Pose Index", description="", override = {'LIBRARY_OVERRIDABLE'}) 
    pose_new_name: bpy.props.StringProperty(name="Pose Name", description="New name for pose", default="Pose", override = {'LIBRARY_OVERRIDABLE'})
    only_selected: bpy.props.BoolProperty(name="Only selected Bones", description="Process only selected bones", default=False, options={'HIDDEN'}, override = {'LIBRARY_OVERRIDABLE'})

classes = (dsplObj, dsplVars)

def register():
    from bpy.utils import register_class
    for cls in classes:
        register_class(cls)

    gui.register()
    operators.register()

    bpy.types.Object.dspl = bpy.props.PointerProperty(type = dsplObj, override = {'LIBRARY_OVERRIDABLE'})
    bpy.types.Object.dsplvars = bpy.props.PointerProperty(type = dsplVars, override = {'LIBRARY_OVERRIDABLE'})

def unregister() -> None:
    from bpy.utils import unregister_class
    for cls in classes:
        unregister_class(cls)
    
    gui.unregister()
    operators.unregister()

    del bpy.types.Object.dspl
    del bpy.types.Object.dsplvars

if __name__ == "__main__":
    register()